=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2006-06-12 02:11:45 +0000
+++ bzrlib/branch.py	2006-06-15 17:26:25 +0000
@@ -332,17 +332,21 @@
         >>> br1.missing_revisions(br2)
         []
         >>> wt2.commit("lala!", rev_id="REVISION-ID-1")
+        'REVISION-ID-1'
         >>> br1.missing_revisions(br2)
         [u'REVISION-ID-1']
         >>> br2.missing_revisions(br1)
         []
         >>> wt1.commit("lala!", rev_id="REVISION-ID-1")
+        'REVISION-ID-1'
         >>> br1.missing_revisions(br2)
         []
         >>> wt2.commit("lala!", rev_id="REVISION-ID-2A")
+        'REVISION-ID-2A'
         >>> br1.missing_revisions(br2)
         [u'REVISION-ID-2A']
         >>> wt1.commit("lala!", rev_id="REVISION-ID-2B")
+        'REVISION-ID-2B'
         >>> br1.missing_revisions(br2)
         Traceback (most recent call last):
         DivergedBranches: These branches have diverged.  Try merge.

=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2006-06-13 11:44:27 +0000
+++ bzrlib/commit.py	2006-06-15 17:26:25 +0000
@@ -98,7 +98,7 @@
 
     New code should use the Commit class instead.
     """
-    ## XXX: Remove this in favor of Branch.commit?
+    ## XXX: Remove this in favor of WorkingTree.commit?
     Commit().commit(*args, **kwargs)
 
 
@@ -343,6 +343,7 @@
             self._emit_progress_update()
         finally:
             self._cleanup()
+        return self.rev_id
 
     def _check_bound_branch(self):
         """Check to see if the local branch is bound.

=== modified file 'bzrlib/tests/workingtree_implementations/test_commit.py'
--- bzrlib/tests/workingtree_implementations/test_commit.py	2006-06-08 14:17:29 +0000
+++ bzrlib/tests/workingtree_implementations/test_commit.py	2006-06-15 17:26:25 +0000
@@ -89,8 +89,16 @@
 
     def test_commit_sets_last_revision(self):
         tree = self.make_branch_and_tree('tree')
-        tree.commit('foo', rev_id='foo', allow_pointless=True)
+        committed_id = tree.commit('foo', rev_id='foo', allow_pointless=True)
         self.assertEqual('foo', tree.last_revision())
+        # the commit should have returned the same id we asked for.
+        self.assertEqual('foo', committed_id)
+
+    def test_commit_returns_revision_id(self):
+        tree = self.make_branch_and_tree('.')
+        committed_id = tree.commit('message', allow_pointless=True)
+        self.assertTrue(tree.branch.repository.has_revision(committed_id))
+        self.assertNotEqual(None, committed_id)
 
     def test_commit_local_unbound(self):
         # using the library api to do a local commit on unbound branches is 

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2006-06-13 16:26:09 +0000
+++ bzrlib/workingtree.py	2006-06-15 17:26:25 +0000
@@ -509,8 +509,10 @@
         # but with branch a kwarg now, passing in args as is results in the
         #message being used for the branch
         args = (DEPRECATED_PARAMETER, message, ) + args
-        Commit().commit(working_tree=self, revprops=revprops, *args, **kwargs)
+        committed_id = Commit().commit( working_tree=self, revprops=revprops,
+            *args, **kwargs)
         self._set_inventory(self.read_working_inventory())
+        return committed_id
 
     def id2abspath(self, file_id):
         return self.abspath(self.id2path(file_id))

